class WKTValidator:
    coord_params = {
        'POINT': {'level': 1, 'min': 1, 'len_point': 2},
        'POINT Z': {'level': 1, 'min': 1, 'len_point': 3},
        'LINESTRING': {'level': 1, 'min': 2, 'len_point': 2},
        'LINESTRING Z': {'level': 1, 'min': 2, 'len_point': 3},
        'POLYGON': {'level': 2, 'min': 3, 'len_point': 2},
        'POLYGON Z': {'level': 2, 'min': 3, 'len_point': 3},
        'MULTIPOINT': {'level': 2, 'min': 1, 'len_point': 2},
        'MULTIPOINT Z': {'level': 2, 'min': 1, 'len_point': 3},
        'MULTILINESTRING': {'level': 2, 'min': 2, 'len_point': 2},
        'MULTILINESTRING Z': {'level': 2, 'min': 2, 'len_point': 3},
        'MULTIPOLYGON': {'level': 3, 'min': 3, 'len_point': 2},
        'MULTIPOLYGON Z': {'level': 3, 'min': 3, 'len_point': 3},
        'GEOMETRYCOLLECTION': 0
    }

    @classmethod
    def split_and_add_to_list(cls, coords_list: list, coords_str: str):
        if coords_str.startswith('('):
            coords_str = coords_str[1:-1]
            for new_coords_str in coords_str.split('),('):
                new_list = []
                cls.split_and_add_to_list(coords_list=new_list, coords_str=new_coords_str)
                coords_list.append(new_list)
        else:
            for c in coords_str.split(','):
                x_y_z = tuple(float(co) for co in c.strip().split(' '))
                coords_list.append(x_y_z)

    @classmethod
    def validate_wkt(cls, input_string: str) -> bool:
        if '(' not in input_string or ')' not in input_string:
            return False
        input_string = input_string.upper()
        geo_type = input_string.split(' (')[0]

        if geo_type not in (
                'POINT', 'POINT Z', 'LINESTRING', 'LINESTRING Z', 'POLYGON', 'POLYGON Z', 'MULTIPOINT', 'MULTIPOINT Z',
                'MULTILINESTRING', 'MULTILINESTRING Z', 'MULTIPOLYGON', 'MULTIPOLYGON Z', 'GEOMETRYCOLLECTION'):
            return False

        coords_list = cls.get_coords_list_from_wkt_string(input_string)

        level = cls.coord_params[geo_type]['level']
        if level == 1 and not isinstance(coords_list[0], tuple):
            return False
        elif level == 2 and not isinstance(coords_list[0][0], tuple):
            return False
        elif level == 3 and not isinstance(coords_list[0][0][0], tuple):
            return False
        # TODO: if level == 0

        if level == 1:
            return cls.validate_coords_list(coords_list, geo_type)
        elif level == 2:
            for coords in coords_list:
                if not cls.validate_coords_list(coords, geo_type):
                    return False
            return True
        elif level == 3:
            for coords in coords_list:
                for coords2 in coords:
                    if not cls.validate_coords_list(coords2, geo_type):
                        return False
            return True

    @classmethod
    def get_coords_list_from_wkt_string(cls, input_string):
        coords_string = input_string.split(' (')[1][:-1].replace(', ', ',').replace(' ,', ',')
        coords_list = []
        cls.split_and_add_to_list(coords_list, coords_string)
        return coords_list

    @classmethod
    def validate_coords_list(cls, coords_list, geo_type):
        len_point = cls.coord_params[geo_type]['len_point']
        min_point = cls.coord_params[geo_type]['min']

        if len(coords_list) < min_point:
            return False

        for point in coords_list:
            if geo_type.endswith(' Z') and len(point) != len_point:
                return False
            if not geo_type.endswith(' Z') and len(point) != len_point:
                return False

            val_0 = point[0]
            if val_0 < 14637.2 or val_0 > 291015.3:
               return False
            val_1 = point[1]
            if val_1 < 22608.2 or val_1 > 246424.3:
                return False
            if len_point == 3:
                if point[2] > 700:
                    return False

        return True



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlWeergegevenVervoersmodiOpKaart(KeuzelijstField):
    """De verschillende beschikbare vervoersmodi die op de bijhorende kaart worden meegegeven."""
    naam = 'KlWeergegevenVervoersmodiOpKaart'
    label = 'Weergegeven vervoersmodi op kaart'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlWeergegevenVervoersmodiOpKaart'
    definition = 'De verschillende beschikbare vervoersmodi die op de bijhorende kaart worden meegegeven.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlWeergegevenVervoersmodiOpKaart'
    options = {
        'bus': KeuzelijstWaarde(invulwaarde='bus',
                                label='Bus',
                                status='ingebruik',
                                definitie='Bus',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/bus'),
        'deelauto': KeuzelijstWaarde(invulwaarde='deelauto',
                                     label='Deelauto',
                                     status='ingebruik',
                                     definitie='TODO',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/deelauto'),
        'deelbakfiets': KeuzelijstWaarde(invulwaarde='deelbakfiets',
                                         label='Deelbakfiets',
                                         status='ingebruik',
                                         definitie='Deelbakfiets',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/deelbakfiets'),
        'deelbolderkar': KeuzelijstWaarde(invulwaarde='deelbolderkar',
                                          label='Deelbolderkar',
                                          status='ingebruik',
                                          definitie='Deelbolderkar',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/deelbolderkar'),
        'deelbuggy': KeuzelijstWaarde(invulwaarde='deelbuggy',
                                      label='Deelbuggy',
                                      status='ingebruik',
                                      definitie='Deelbuggy',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/deelbuggy'),
        'deelfiets': KeuzelijstWaarde(invulwaarde='deelfiets',
                                      label='Deelfiets',
                                      status='ingebruik',
                                      definitie='TODO',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/deelfiets'),
        'deelrolstoel': KeuzelijstWaarde(invulwaarde='deelrolstoel',
                                         label='Deelrolstoel',
                                         status='ingebruik',
                                         definitie='Deelrolstoel',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/deelrolstoel'),
        'deelstep': KeuzelijstWaarde(invulwaarde='deelstep',
                                     label='Deelstep',
                                     status='ingebruik',
                                     definitie='Deelstep',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/deelstep'),
        'deelwagen': KeuzelijstWaarde(invulwaarde='deelwagen',
                                      label='Deelwagen',
                                      status='ingebruik',
                                      definitie='Deelwagen',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/deelwagen'),
        'e-deelbakfiets': KeuzelijstWaarde(invulwaarde='e-deelbakfiets',
                                           label='e-deelbakfiets',
                                           status='ingebruik',
                                           definitie='e-deelbakfiets',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/e-deelbakfiets'),
        'e-deelfiets': KeuzelijstWaarde(invulwaarde='e-deelfiets',
                                        label='e-deelfiets',
                                        status='ingebruik',
                                        definitie='e-deelfiets',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/e-deelfiets'),
        'e-deelstep': KeuzelijstWaarde(invulwaarde='e-deelstep',
                                       label='e-deelstep',
                                       status='ingebruik',
                                       definitie='e-deelstep',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/e-deelstep'),
        'e-deelwagen': KeuzelijstWaarde(invulwaarde='e-deelwagen',
                                        label='e-deelwagen',
                                        status='ingebruik',
                                        definitie='e-deelwagen',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/e-deelwagen'),
        'flex': KeuzelijstWaarde(invulwaarde='flex',
                                 label='Flex',
                                 status='ingebruik',
                                 definitie='Flex',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/flex'),
        'flex-2': KeuzelijstWaarde(invulwaarde='flex-2',
                                   label='Flex+',
                                   status='ingebruik',
                                   definitie='Flex+',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/flex-2'),
        'flexvervoer': KeuzelijstWaarde(invulwaarde='flexvervoer',
                                        label='Flexvervoer',
                                        status='ingebruik',
                                        definitie='TODO',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/flexvervoer'),
        'kernnet-aanvullend-net': KeuzelijstWaarde(invulwaarde='kernnet-aanvullend-net',
                                                   label='Kernnet - aanvullend net',
                                                   status='ingebruik',
                                                   definitie='TODO',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/kernnet-aanvullend-net'),
        'metro': KeuzelijstWaarde(invulwaarde='metro',
                                  label='Metro',
                                  status='ingebruik',
                                  definitie='Metro',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/metro'),
        'taxi': KeuzelijstWaarde(invulwaarde='taxi',
                                 label='Taxi',
                                 status='ingebruik',
                                 definitie='Taxi',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/taxi'),
        'tram': KeuzelijstWaarde(invulwaarde='tram',
                                 label='Tram',
                                 status='ingebruik',
                                 definitie='Tram',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/tram'),
        'trein': KeuzelijstWaarde(invulwaarde='trein',
                                  label='Trein',
                                  status='ingebruik',
                                  definitie='Trein',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/trein'),
        'treinnet': KeuzelijstWaarde(invulwaarde='treinnet',
                                     label='Treinnet',
                                     status='ingebruik',
                                     definitie='TODO',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/treinnet'),
        'vast-en-semiflex': KeuzelijstWaarde(invulwaarde='vast-en-semiflex',
                                             label='Vast en semiflex',
                                             status='ingebruik',
                                             definitie='TODO',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeergegevenVervoersmodiOpKaart/vast-en-semiflex')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlOperationeleStatus(KeuzelijstField):
    """Operationele status codes."""
    naam = 'KlOperationeleStatus'
    label = 'Keuzelijst operationele status'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlOperationeleStatus'
    definition = 'Operationele status codes.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlOperationeleStatus'
    options = {
        'actief': KeuzelijstWaarde(invulwaarde='actief',
                                   label='actief',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlOperationeleStatus/actief'),
        'actief-met-geplande-verwijdering': KeuzelijstWaarde(invulwaarde='actief-met-geplande-verwijdering',
                                                             label='actief met geplande verwijdering',
                                                             status='ingebruik',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlOperationeleStatus/actief-met-geplande-verwijdering'),
        'actief-met-geplande-wijziging': KeuzelijstWaarde(invulwaarde='actief-met-geplande-wijziging',
                                                          label='actief met geplande wijziging',
                                                          status='ingebruik',
                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlOperationeleStatus/actief-met-geplande-wijziging'),
        'actief-met-tijdelijke-wijziging': KeuzelijstWaarde(invulwaarde='actief-met-tijdelijke-wijziging',
                                                            label='actief met tijdelijke wijziging',
                                                            status='ingebruik',
                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlOperationeleStatus/actief-met-tijdelijke-wijziging'),
        'tijdelijk-actief': KeuzelijstWaarde(invulwaarde='tijdelijk-actief',
                                             label='tijdelijk actief',
                                             status='ingebruik',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlOperationeleStatus/tijdelijk-actief'),
        'tijdelijk-inactief': KeuzelijstWaarde(invulwaarde='tijdelijk-inactief',
                                               label='tijdelijk inactief',
                                               status='ingebruik',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlOperationeleStatus/tijdelijk-inactief')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Beginstuk import Beginstuk
from ...Datatypes.KlLEACUitbuigingstype import KlLEACUitbuigingstype


# Generated with OTLClassCreator. To modify: extend, do not edit
class NietGetestBeginstuk(Beginstuk):
    """Een niet-gecertificeerd begin aan een geleideconstructie, aan de stroomopwaartse zijde ten opzichte van de meest nabij gelegen rijstrook."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#NietGetestBeginstuk'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Fundering')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Motorvangplank')

        self._uitbuigingstype = OTLAttribuut(field=KlLEACUitbuigingstype,
                                             naam='uitbuigingstype',
                                             label='uitbuigingstype',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#NietGetestBeginstuk.uitbuigingstype',
                                             definition='Niet getest beginstuk dat uitbuigt weg van de weg in grondplan.',
                                             owner=self)

    @property
    def uitbuigingstype(self) -> str:
        """Niet getest beginstuk dat uitbuigt weg van de weg in grondplan."""
        return self._uitbuigingstype.get_waarde()

    @uitbuigingstype.setter
    def uitbuigingstype(self, value):
        self._uitbuigingstype.set_waarde(value, owner=self)



from abc import abstractmethod


class RelationInteractor:
    typeURI = ''
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def add_valid_relation(self, relation: str, target: str, deprecated: str = ''):
        if relation not in self._valid_relations:
            self._valid_relations[relation] = {}
        self._valid_relations[relation][target] = deprecated

    @abstractmethod
    def __init__(self):
        super().__init__()

        self._valid_relations = {}



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.BevestigingGC import BevestigingGC
from ...Classes.Abstracten.Signalisatie import Signalisatie
from ...Classes.ImplementatieElement.AIMObject import AIMObject
from ...Datatypes.DteTekstblok import DteTekstblok, DteTekstblokWaarden
from ...Datatypes.KlSignalisatieReferentiepuntType import KlSignalisatieReferentiepuntType


# Generated with OTLClassCreator. To modify: extend, do not edit
class Referentiepunt(BevestigingGC, Signalisatie, AIMObject):
    """Een kilometer- of hectometerpaal."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Referentiepunt'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AfschermendeConstructie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#StalenProfiel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#GeluidswerendeConstructie', deprecated='2.0.0')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#WegbebakeningAfschermendeConstructies')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Meetstation')

        self._opschrift = OTLAttribuut(field=DteTekstblok,
                                       naam='opschrift',
                                       label='opschrift',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Referentiepunt.opschrift',
                                       definition='De notatie van het referentiepunt.',
                                       owner=self)

        self._type = OTLAttribuut(field=KlSignalisatieReferentiepuntType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Referentiepunt.type',
                                  definition='Het type van referentiepunt.',
                                  owner=self)

    @property
    def opschrift(self) -> DteTekstblokWaarden:
        """De notatie van het referentiepunt."""
        return self._opschrift.get_waarde()

    @opschrift.setter
    def opschrift(self, value):
        self._opschrift.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Het type van referentiepunt."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.Onderdeel.Ruigte import Ruigte


# Generated with OTLClassCreator. To modify: extend, do not edit
class VerstoordGrasland(Ruigte):
    """R1 - duinriet, kruipertje, gewone raket, bijvoet, fijnstraal spec., kleine brandnetel, boerenwormkruid, kamille spec., varkensgras, akkerdistel, klein kaasjeskruid, teunisbloem spec., honingklaver spec., grote kaardebol, stinkende ballote, kompassla, zeepkruid, wilde reseda, ijle dravik, kleine ooievaarsbek, kruldistel, slangenkruid, klein hoefblad, akkerwinde, kweek, heermoes, grote klaproos, herderstasje, paarse dovenetel, perzikkruid, vogelmuur, akkerkool"""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerstoordGrasland'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlAfmetingsensorMerk(KeuzelijstField):
    """Het merk van de afmetingsensor."""
    naam = 'KlAfmetingsensorMerk'
    label = 'Afmetingsensor merk'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlAfmetingsensorMerk'
    definition = 'Het merk van de afmetingsensor.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlAfmetingsensorMerk'
    options = {
        'Sick': KeuzelijstWaarde(invulwaarde='Sick',
                                 label='Sick',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfmetingsensorMerk/Sick')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlUitlaatType(KeuzelijstField):
    """De verschillende types van uitlaat."""
    naam = 'KlUitlaatType'
    label = 'Uitlaat type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlUitlaatType'
    definition = 'De verschillende types van uitlaat.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlUitlaatType'
    options = {
        'inlaat': KeuzelijstWaarde(invulwaarde='inlaat',
                                   label='inlaat',
                                   status='ingebruik',
                                   definitie='locatie waar water van een open profiel naar een inbuizing overgaat',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlUitlaatType/inlaat'),
        'uitlaat': KeuzelijstWaarde(invulwaarde='uitlaat',
                                    label='uitlaat',
                                    status='ingebruik',
                                    definitie='locatie waar water van een inbuizing naar een open profiel overgaat',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlUitlaatType/uitlaat')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlNetwerkelemModelnaam(KeuzelijstField):
    """Modelnamen voor Netwerkelementen."""
    naam = 'KlNetwerkelemModelnaam'
    label = 'Netwerkelement modelnaam'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlNetwerkelemModelnaam'
    definition = 'Modelnamen voor Netwerkelementen.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlNetwerkelemModelnaam'
    options = {
        '1322VD': KeuzelijstWaarde(invulwaarde='1322VD',
                                   label='1322VD',
                                   status='ingebruik',
                                   definitie='1322VD',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/1322VD'),
        '1511BA': KeuzelijstWaarde(invulwaarde='1511BA',
                                   label='1511BA',
                                   status='ingebruik',
                                   definitie='1511BA',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/1511BA'),
        '1515CXC': KeuzelijstWaarde(invulwaarde='1515CXC',
                                    label='1515CXC',
                                    status='ingebruik',
                                    definitie='1515CXC',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/1515CXC'),
        '2150': KeuzelijstWaarde(invulwaarde='2150',
                                 label='2150',
                                 status='ingebruik',
                                 definitie='2150',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/2150'),
        '3916': KeuzelijstWaarde(invulwaarde='3916',
                                 label='3916',
                                 status='ingebruik',
                                 definitie='3916',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/3916'),
        '3924': KeuzelijstWaarde(invulwaarde='3924',
                                 label='3924',
                                 status='ingebruik',
                                 definitie='3924',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/3924'),
        '3926': KeuzelijstWaarde(invulwaarde='3926',
                                 label='3926',
                                 status='ingebruik',
                                 definitie='3926',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/3926'),
        '3928': KeuzelijstWaarde(invulwaarde='3928',
                                 label='3928',
                                 status='ingebruik',
                                 definitie='3928',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/3928'),
        '3930': KeuzelijstWaarde(invulwaarde='3930',
                                 label='3930',
                                 status='ingebruik',
                                 definitie='3930',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/3930'),
        '3942': KeuzelijstWaarde(invulwaarde='3942',
                                 label='3942',
                                 status='ingebruik',
                                 definitie='3942',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/3942'),
        '4200Classic': KeuzelijstWaarde(invulwaarde='4200Classic',
                                        label='4200Classic',
                                        status='ingebruik',
                                        definitie='4200Classic',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/4200Classic'),
        '4200Micro': KeuzelijstWaarde(invulwaarde='4200Micro',
                                      label='4200Micro',
                                      status='ingebruik',
                                      definitie='4200Micro',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/4200Micro'),
        '4200RS': KeuzelijstWaarde(invulwaarde='4200RS',
                                   label='4200RS',
                                   status='ingebruik',
                                   definitie='4200RS',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/4200RS'),
        '5142': KeuzelijstWaarde(invulwaarde='5142',
                                 label='5142',
                                 status='ingebruik',
                                 definitie='5142',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/5142'),
        '5160': KeuzelijstWaarde(invulwaarde='5160',
                                 label='5160',
                                 status='ingebruik',
                                 definitie='5160',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/5160'),
        '5170': KeuzelijstWaarde(invulwaarde='5170',
                                 label='5170',
                                 status='ingebruik',
                                 definitie='5170',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/5170'),
        '5171': KeuzelijstWaarde(invulwaarde='5171',
                                 label='5171',
                                 status='ingebruik',
                                 definitie='5171',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/5171'),
        '6500-D14': KeuzelijstWaarde(invulwaarde='6500-D14',
                                     label='6500-D14',
                                     status='ingebruik',
                                     definitie='6500-D14',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/6500-D14'),
        '6500-D2': KeuzelijstWaarde(invulwaarde='6500-D2',
                                    label='6500-D2',
                                    status='ingebruik',
                                    definitie='6500-D2',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/6500-D2'),
        '6500-D7': KeuzelijstWaarde(invulwaarde='6500-D7',
                                    label='6500-D7',
                                    status='ingebruik',
                                    definitie='6500-D7',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/6500-D7'),
        '6500-S14': KeuzelijstWaarde(invulwaarde='6500-S14',
                                     label='6500-S14',
                                     status='ingebruik',
                                     definitie='6500-S14',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/6500-S14'),
        '6500-S32': KeuzelijstWaarde(invulwaarde='6500-S32',
                                     label='6500-S32',
                                     status='ingebruik',
                                     definitie='6500-S32',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/6500-S32'),
        '6500-S8': KeuzelijstWaarde(invulwaarde='6500-S8',
                                    label='6500-S8',
                                    status='ingebruik',
                                    definitie='6500-S8',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/6500-S8'),
        'ADMU': KeuzelijstWaarde(invulwaarde='ADMU',
                                 label='ADMU',
                                 status='ingebruik',
                                 definitie='ADMU',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ADMU'),
        'AM1+': KeuzelijstWaarde(invulwaarde='AM1+',
                                 label='AM1+',
                                 status='ingebruik',
                                 definitie='AM1+',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/AM1+'),
        'AMC': KeuzelijstWaarde(invulwaarde='AMC',
                                label='AMC',
                                status='ingebruik',
                                definitie='AMC',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/AMC'),
        'AMS': KeuzelijstWaarde(invulwaarde='AMS',
                                label='AMS',
                                status='ingebruik',
                                definitie='AMS',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/AMS'),
        'AMU1slot': KeuzelijstWaarde(invulwaarde='AMU1slot',
                                     label='AMU1slot',
                                     status='ingebruik',
                                     definitie='AMU1slot',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/AMU1slot'),
        'AMU4slot': KeuzelijstWaarde(invulwaarde='AMU4slot',
                                     label='AMU4slot',
                                     status='ingebruik',
                                     definitie='AMU4slot',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/AMU4slot'),
        'NULL': KeuzelijstWaarde(invulwaarde='NULL',
                                 label='NULL',
                                 status='ingebruik',
                                 definitie='NULL',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/NULL'),
        'OMS': KeuzelijstWaarde(invulwaarde='OMS',
                                label='OMS',
                                status='ingebruik',
                                definitie='OMS',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/OMS'),
        'Other': KeuzelijstWaarde(invulwaarde='Other',
                                  label='Other',
                                  status='ingebruik',
                                  definitie='Other',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/Other'),
        'air': KeuzelijstWaarde(invulwaarde='air',
                                label='AIR',
                                status='ingebruik',
                                definitie='AIR',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/air'),
        'c1800': KeuzelijstWaarde(invulwaarde='c1800',
                                  label='C1800',
                                  status='ingebruik',
                                  definitie='C1800',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c1800'),
        'c2950': KeuzelijstWaarde(invulwaarde='c2950',
                                  label='C2950',
                                  status='ingebruik',
                                  definitie='C2950',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c2950'),
        'c2960': KeuzelijstWaarde(invulwaarde='c2960',
                                  label='C2960',
                                  status='ingebruik',
                                  definitie='C2960',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c2960'),
        'c3550': KeuzelijstWaarde(invulwaarde='c3550',
                                  label='C3550',
                                  status='ingebruik',
                                  definitie='C3550',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c3550'),
        'c3560': KeuzelijstWaarde(invulwaarde='c3560',
                                  label='C3560',
                                  status='ingebruik',
                                  definitie='C3560',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c3560'),
        'c3650': KeuzelijstWaarde(invulwaarde='c3650',
                                  label='C3650',
                                  status='ingebruik',
                                  definitie='C3650',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c3650'),
        'c3750': KeuzelijstWaarde(invulwaarde='c3750',
                                  label='C3750',
                                  status='ingebruik',
                                  definitie='C3750',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c3750'),
        'c3850': KeuzelijstWaarde(invulwaarde='c3850',
                                  label='C3850',
                                  status='ingebruik',
                                  definitie='C3850',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c3850'),
        'c880': KeuzelijstWaarde(invulwaarde='c880',
                                 label='C880',
                                 status='ingebruik',
                                 definitie='C880',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c880'),
        'c9300': KeuzelijstWaarde(invulwaarde='c9300',
                                  label='C9300',
                                  status='ingebruik',
                                  definitie='C9300',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c9300'),
        'fgt': KeuzelijstWaarde(invulwaarde='fgt',
                                label='FGT',
                                status='ingebruik',
                                definitie='FGT',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/fgt'),
        'hiveap-122': KeuzelijstWaarde(invulwaarde='hiveap-122',
                                       label='HiveAP 122',
                                       status='ingebruik',
                                       definitie='HiveAP 122',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/hiveap-122'),
        'ie-1000': KeuzelijstWaarde(invulwaarde='ie-1000',
                                    label='IE-1000',
                                    status='ingebruik',
                                    definitie='IE-1000',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ie-1000'),
        'ie-2000': KeuzelijstWaarde(invulwaarde='ie-2000',
                                    label='IE-2000',
                                    status='ingebruik',
                                    definitie='IE-2000',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ie-2000'),
        'ie-3000': KeuzelijstWaarde(invulwaarde='ie-3000',
                                    label='IE-3000',
                                    status='ingebruik',
                                    definitie='IE-3000',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ie-3000'),
        'ie-4000': KeuzelijstWaarde(invulwaarde='ie-4000',
                                    label='IE-4000',
                                    status='ingebruik',
                                    definitie='IE-4000',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ie-4000'),
        'ir1100': KeuzelijstWaarde(invulwaarde='ir1100',
                                   label='IR1100',
                                   status='ingebruik',
                                   definitie='IR1100',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ir1100'),
        'ir800': KeuzelijstWaarde(invulwaarde='ir800',
                                  label='IR800',
                                  status='ingebruik',
                                  definitie='IR800',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ir800'),
        'lgx-rck-2-1u': KeuzelijstWaarde(invulwaarde='lgx-rck-2-1u',
                                         label='LGX-RCK-2-1U',
                                         status='ingebruik',
                                         definitie='LGX-RCK-2-1U',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/lgx-rck-2-1u'),
        'mar1030': KeuzelijstWaarde(invulwaarde='mar1030',
                                    label='MAR1030',
                                    status='ingebruik',
                                    definitie='MAR1030',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/mar1030'),
        'mar1040': KeuzelijstWaarde(invulwaarde='mar1040',
                                    label='MAR1040',
                                    status='ingebruik',
                                    definitie='MAR1040',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/mar1040'),
        'ml530': KeuzelijstWaarde(invulwaarde='ml530',
                                  label='ML530',
                                  status='ingebruik',
                                  definitie='ML530',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ml530'),
        'ml620': KeuzelijstWaarde(invulwaarde='ml620',
                                  label='ML620',
                                  status='ingebruik',
                                  definitie='ML620',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ml620'),
        'ml680': KeuzelijstWaarde(invulwaarde='ml680',
                                  label='ML680',
                                  status='ingebruik',
                                  definitie='ML680',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ml680'),
        'nexus': KeuzelijstWaarde(invulwaarde='nexus',
                                  label='NEXUS',
                                  status='ingebruik',
                                  definitie='NEXUS',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/nexus'),
        'rs30': KeuzelijstWaarde(invulwaarde='rs30',
                                 label='RS30',
                                 status='ingebruik',
                                 definitie='RS30',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/rs30')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Behuizing import Behuizing
from ...Datatypes.DtcAfmetingBxlxhInMm import DtcAfmetingBxlxhInMm, DtcAfmetingBxlxhInMmWaarden
from ...Datatypes.KlAlgIngressProtectionCode import KlAlgIngressProtectionCode
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Doorverbinddoos(Behuizing, PuntGeometrie):
    """Een behuizing waarin kabels aan elkaar gekoppeld worden om over te gaan van het ene naar het andere type of de splitsen of samen te komen. De behuizing is niet voorzien van een deur en kan enkel geopend worden met het geschikte gereedschap."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Doorverbinddoos'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Draagconstructie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kabel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Toegangselement')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#MIVLus')

        self._buitenafmetingen = OTLAttribuut(field=DtcAfmetingBxlxhInMm,
                                              naam='buitenafmetingen',
                                              label='buitenafmetingen',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Doorverbinddoos.buitenafmetingen',
                                              definition='De afmeting van de buitenkant van de doorverbinddoos.',
                                              owner=self)

        self._ipKlasse = OTLAttribuut(field=KlAlgIngressProtectionCode,
                                      naam='ipKlasse',
                                      label='ingress protection klasse',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Doorverbinddoos.ipKlasse',
                                      definition='De IP-codering als een aanduiding voor de mate van beveiliging van de constructie van elektrische of elektronische apparatuur tegen eigen schade door gebruik in "vijandige omgevingen" en tegen eventueel gevaar voor de gebruiker volgens IEC 60529.',
                                      owner=self)

    @property
    def buitenafmetingen(self) -> DtcAfmetingBxlxhInMmWaarden:
        """De afmeting van de buitenkant van de doorverbinddoos."""
        return self._buitenafmetingen.get_waarde()

    @buitenafmetingen.setter
    def buitenafmetingen(self, value):
        self._buitenafmetingen.set_waarde(value, owner=self)

    @property
    def ipKlasse(self) -> str:
        """De IP-codering als een aanduiding voor de mate van beveiliging van de constructie van elektrische of elektronische apparatuur tegen eigen schade door gebruik in "vijandige omgevingen" en tegen eventueel gevaar voor de gebruiker volgens IEC 60529."""
        return self._ipKlasse.get_waarde()

    @ipKlasse.setter
    def ipKlasse(self, value):
        self._ipKlasse.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.Abstracten.Verkeerslicht import Verkeerslicht


# Generated with OTLClassCreator. To modify: extend, do not edit
class VerkeerslichtGroen(Verkeerslicht):
    """Een lichtbron met groene kleur om de weggebruikers aan te geven dat het verkeerslicht mag voorbijgereden worden."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerkeerslichtGroen'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn')



# coding=utf-8
from abc import abstractmethod
from ...Classes.Abstracten.FirmwareObject import FirmwareObject
from ...Classes.Abstracten.PTRegelaarModule import PTRegelaarModule


# Generated with OTLClassCreator. To modify: extend, do not edit
class PTModuleMetFirmware(FirmwareObject, PTRegelaarModule):
    """Abstracte voor de modules met firmware van het personentransportbeïnvloedingssysteem van een verkeersregelaar."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#PTModuleMetFirmware'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Onderdeel.Funderingspaal import Funderingspaal
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KlInbrengmethode import KlInbrengmethode
from ...Datatypes.KwantWrdInMeterTAW import KwantWrdInMeterTAW, KwantWrdInMeterTAWWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class StalenFunderingsprofiel(Funderingspaal):
    """Stalen profiel, bijvoorbeeld een H-profiel, dat wordt gebruikt als fundering of wapening van een fundering. Dit is geen profiel voor een damwand: hiervoor moet 'Stalen damplank' worden gebruikt."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#StalenFunderingsprofiel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Behuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Grondanker')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Hoppinzuil')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#NietWeggebondenDetectie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SteunStandaard')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Ventilatie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersbord')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Waarschuwingslantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ZenderOntvangerToegang')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Berlinerwand')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Combiwand')

        self._aanzetpeilSlot = OTLAttribuut(field=KwantWrdInMeterTAW,
                                            naam='aanzetpeilSlot',
                                            label='aanzetpeil slot',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#StalenFunderingsprofiel.aanzetpeilSlot',
                                            definition='Aanzetpeil van het slot.',
                                            owner=self)

        self._inbrengmethode = OTLAttribuut(field=KlInbrengmethode,
                                            naam='inbrengmethode',
                                            label='inbrengmethode',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#StalenFunderingsprofiel.inbrengmethode',
                                            definition='Keuzelijst om de inbrengmethode toe te lichten.',
                                            owner=self)

        self._isSlotAanwezig = OTLAttribuut(field=BooleanField,
                                            naam='isSlotAanwezig',
                                            label='is slot aanwezig',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#StalenFunderingsprofiel.isSlotAanwezig',
                                            definition='Geeft aan of er al dan niet een slot aanwezig is.',
                                            owner=self)

    @property
    def aanzetpeilSlot(self) -> KwantWrdInMeterTAWWaarden:
        """Aanzetpeil van het slot."""
        return self._aanzetpeilSlot.get_waarde()

    @aanzetpeilSlot.setter
    def aanzetpeilSlot(self, value):
        self._aanzetpeilSlot.set_waarde(value, owner=self)

    @property
    def inbrengmethode(self) -> str:
        """Keuzelijst om de inbrengmethode toe te lichten."""
        return self._inbrengmethode.get_waarde()

    @inbrengmethode.setter
    def inbrengmethode(self, value):
        self._inbrengmethode.set_waarde(value, owner=self)

    @property
    def isSlotAanwezig(self) -> bool:
        """Geeft aan of er al dan niet een slot aanwezig is."""
        return self._isSlotAanwezig.get_waarde()

    @isSlotAanwezig.setter
    def isSlotAanwezig(self, value):
        self._isSlotAanwezig.set_waarde(value, owner=self)



# coding=utf-8
from datetime import date
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Brandvoorziening import Brandvoorziening
from otlmow_model.OtlmowModel.BaseClasses.DateField import DateField
from ...Datatypes.KlBrandhaspelMerk import KlBrandhaspelMerk
from ...Datatypes.KlBrandhaspelModelnaam import KlBrandhaspelModelnaam
from ...Datatypes.KwantWrdInCentimeter import KwantWrdInCentimeter, KwantWrdInCentimeterWaarden
from ...Datatypes.KwantWrdInKubiekeMeter import KwantWrdInKubiekeMeter, KwantWrdInKubiekeMeterWaarden
from ...Datatypes.KwantWrdInKubiekeMeterPerSeconde import KwantWrdInKubiekeMeterPerSeconde, KwantWrdInKubiekeMeterPerSecondeWaarden
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class Brandhaspel(Brandvoorziening):
    """Een brandslang met spuitmond,opgerold op een haspel."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandhaspel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hulppostkast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hulppost')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Vluchtganginrichting')

        self._buitendiameter = OTLAttribuut(field=KwantWrdInCentimeter,
                                            naam='buitendiameter',
                                            label='buitendiameter',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandhaspel.buitendiameter',
                                            definition='Buitendiameter van de slang op de haspel.',
                                            owner=self)

        self._keuringsdatum = OTLAttribuut(field=DateField,
                                           naam='keuringsdatum',
                                           label='keuringsdatum',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandhaspel.keuringsdatum',
                                           definition='Laatste datum waarop de haspel gekeurd is.',
                                           owner=self)

        self._maximaalDebiet = OTLAttribuut(field=KwantWrdInKubiekeMeter,
                                            naam='maximaalDebiet',
                                            label='maximaalDebiet',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandhaspel.maximaalDebiet',
                                            usagenote='Attribuut uit gebruik sinds versie 2.0.0 ',
                                            deprecated_version='2.0.0',
                                            definition='Het maximale debiet dat door de slang en spuitmond kan stromen.',
                                            owner=self)

        self._maximaalVolumedebiet = OTLAttribuut(field=KwantWrdInKubiekeMeterPerSeconde,
                                                  naam='maximaalVolumedebiet',
                                                  label='maximaal volumedebiet',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandhaspel.maximaalVolumedebiet',
                                                  definition='Het maximale debiet dat per tijdseenheid door de slang en spuitmond kan stromen.',
                                                  owner=self)

        self._merk = OTLAttribuut(field=KlBrandhaspelMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandhaspel.merk',
                                  definition='Het merk van de brandhaspel.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlBrandhaspelModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandhaspel.modelnaam',
                                       definition='De modelnaam van de brandhaspel.',
                                       owner=self)

        self._slangLengte = OTLAttribuut(field=KwantWrdInMeter,
                                         naam='slangLengte',
                                         label='slanglengte',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandhaspel.slangLengte',
                                         definition='Nuttige lengte van de brandslang op de haspel.',
                                         owner=self)

    @property
    def buitendiameter(self) -> KwantWrdInCentimeterWaarden:
        """Buitendiameter van de slang op de haspel."""
        return self._buitendiameter.get_waarde()

    @buitendiameter.setter
    def buitendiameter(self, value):
        self._buitendiameter.set_waarde(value, owner=self)

    @property
    def keuringsdatum(self) -> date:
        """Laatste datum waarop de haspel gekeurd is."""
        return self._keuringsdatum.get_waarde()

    @keuringsdatum.setter
    def keuringsdatum(self, value):
        self._keuringsdatum.set_waarde(value, owner=self)

    @property
    def maximaalDebiet(self) -> KwantWrdInKubiekeMeterWaarden:
        """Het maximale debiet dat door de slang en spuitmond kan stromen."""
        return self._maximaalDebiet.get_waarde()

    @maximaalDebiet.setter
    def maximaalDebiet(self, value):
        self._maximaalDebiet.set_waarde(value, owner=self)

    @property
    def maximaalVolumedebiet(self) -> KwantWrdInKubiekeMeterPerSecondeWaarden:
        """Het maximale debiet dat per tijdseenheid door de slang en spuitmond kan stromen."""
        return self._maximaalVolumedebiet.get_waarde()

    @maximaalVolumedebiet.setter
    def maximaalVolumedebiet(self, value):
        self._maximaalVolumedebiet.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de brandhaspel."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de brandhaspel."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def slangLengte(self) -> KwantWrdInMeterWaarden:
        """Nuttige lengte van de brandslang op de haspel."""
        return self._slangLengte.get_waarde()

    @slangLengte.setter
    def slangLengte(self, value):
        self._slangLengte.set_waarde(value, owner=self)



# coding=utf-8
from typing import List
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMObject import AIMObject
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.DtcExterneReferentie import DtcExterneReferentie, DtcExterneReferentieWaarden
from ...Datatypes.KlVerkeersbordCategorie import KlVerkeersbordCategorie
from ...Datatypes.KlVerkeersbordCode import KlVerkeersbordCode
from ...Datatypes.KlVerkeersbordconceptStatus import KlVerkeersbordconceptStatus
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField
from otlmow_model.OtlmowModel.GeometrieTypes.GeenGeometrie import GeenGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class VerkeersbordConcept(AIMObject, GeenGeometrie):
    """Inhoudelijke definitie van de betekenis van een verkeersbord zoals opgenomen in de wegcode."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VerkeersbordConcept'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._afbeelding = OTLAttribuut(field=DtcDocument,
                                        naam='afbeelding',
                                        label='afbeelding',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VerkeersbordConcept.afbeelding',
                                        kardinaliteit_max='*',
                                        definition='De afbeelding van het verkeersbordconcept.',
                                        owner=self)

        self._betekenis = OTLAttribuut(field=StringField,
                                       naam='betekenis',
                                       label='betekenis',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VerkeersbordConcept.betekenis',
                                       definition='Betekenis die gegeven wordt aan dit soort verkeersbord volgens de wegcode.',
                                       owner=self)

        self._rechtsgrondOnderdeel = OTLAttribuut(field=DtcExterneReferentie,
                                                  naam='rechtsgrondOnderdeel',
                                                  label='rechtsgrondonderdeel',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VerkeersbordConcept.rechtsgrondOnderdeel',
                                                  usagenote='Verwijst meestal naar een artikel in de wegcode die informatie over dit verkeersbordconcept bevat. Bijvoorbeeld: artikel 68.3 voor verbodsborden.',
                                                  definition='Verwijst naar een rechtsgrondonderdeel over dit verkeersbordconcept.',
                                                  owner=self)

        self._status = OTLAttribuut(field=KlVerkeersbordconceptStatus,
                                    naam='status',
                                    label='status',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VerkeersbordConcept.status',
                                    usagenote='Bijvoorbeeld: stabiel, onstabiel, afgeschaft. Een bord met snelheidslimiet van 60 km/u is bijvoorbeeld afgeschaft.',
                                    definition='Duidt of het verkeersbordconcept nog gebruikt wordt.',
                                    owner=self)

        self._verkeersbordCategorie = OTLAttribuut(field=KlVerkeersbordCategorie,
                                                   naam='verkeersbordCategorie',
                                                   label='verkeersbord categorie',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VerkeersbordConcept.verkeersbordCategorie',
                                                   definition='Categorie van het verkeersbordconcept.	.',
                                                   owner=self)

        self._verkeersbordCode = OTLAttribuut(field=KlVerkeersbordCode,
                                              naam='verkeersbordCode',
                                              label='verkeersbordcode',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VerkeersbordConcept.verkeersbordCode',
                                              definition='Code die aan dit soort bord gegeven wordt binnen de wegcode.',
                                              owner=self)

    @property
    def afbeelding(self) -> List[DtcDocumentWaarden]:
        """De afbeelding van het verkeersbordconcept."""
        return self._afbeelding.get_waarde()

    @afbeelding.setter
    def afbeelding(self, value):
        self._afbeelding.set_waarde(value, owner=self)

    @property
    def betekenis(self) -> str:
        """Betekenis die gegeven wordt aan dit soort verkeersbord volgens de wegcode."""
        return self._betekenis.get_waarde()

    @betekenis.setter
    def betekenis(self, value):
        self._betekenis.set_waarde(value, owner=self)

    @property
    def rechtsgrondOnderdeel(self) -> DtcExterneReferentieWaarden:
        """Verwijst naar een rechtsgrondonderdeel over dit verkeersbordconcept."""
        return self._rechtsgrondOnderdeel.get_waarde()

    @rechtsgrondOnderdeel.setter
    def rechtsgrondOnderdeel(self, value):
        self._rechtsgrondOnderdeel.set_waarde(value, owner=self)

    @property
    def status(self) -> str:
        """Duidt of het verkeersbordconcept nog gebruikt wordt."""
        return self._status.get_waarde()

    @status.setter
    def status(self, value):
        self._status.set_waarde(value, owner=self)

    @property
    def verkeersbordCategorie(self) -> str:
        """Categorie van het verkeersbordconcept.	."""
        return self._verkeersbordCategorie.get_waarde()

    @verkeersbordCategorie.setter
    def verkeersbordCategorie(self, value):
        self._verkeersbordCategorie.set_waarde(value, owner=self)

    @property
    def verkeersbordCode(self) -> str:
        """Code die aan dit soort bord gegeven wordt binnen de wegcode."""
        return self._verkeersbordCode.get_waarde()

    @verkeersbordCode.setter
    def verkeersbordCode(self, value):
        self._verkeersbordCode.set_waarde(value, owner=self)



from collections import defaultdict
from pathlib import Path
from typing import Iterable, List

from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLObject, create_dict_from_asset


def count_assets_by_type(objects: Iterable[OTLObject]) -> defaultdict:
    d = defaultdict(int)
    for i in objects:
        d[i.typeURI] += 1
    return d


def print_overview_assets(objects: Iterable[OTLObject]) -> None:
    for k, v in count_assets_by_type(objects).items():
        print(f'counting {str(v)} assets of type {k}')


# TODO move to converter (this is using a dotnotation)
def remove_duplicates_in_iterable_based_on_property(iterable: Iterable[OTLObject], property_name: str) -> []:
    d = {}
    for asset in iterable:
        item = asset
        last = property_name
        while '.' in last:
            first = last.split('.')[0]
            last = last.split('.', 1)[1]
            if hasattr(item, first):
                item = getattr(item, first)
                if isinstance(item, list):
                    raise NotImplementedError(
                        "can't use remove_duplicates_in_iterable_based_on_property() when the property value is a list")
        if hasattr(item, last):
            item_prop = getattr(item, last)
            if isinstance(item_prop, list):
                raise NotImplementedError(
                    "can't use remove_duplicates_in_iterable_based_on_property() when the property value is a list")
            item_prop_str = str(item_prop)
            if item_prop_str not in d:
                d[item_prop_str] = asset
    return list(d.values())


def compare_two_lists_of_objects_object_level(first_list: List[OTLObject], second_list: List[OTLObject],
                                              model_directory=None) -> List:
    """Given two lists of objects return the differences from the second list compared to the first list.
    Returns full objects from the second list when unmatched with the first list. """
    l1 = list(map(lambda x: create_dict_from_asset(x), first_list))
    l2 = list(map(lambda x: create_dict_from_asset(x), second_list))
    diff_list = [d for d in l2 if d not in l1]
    return list(map(lambda x: OTLObject.from_dict(x, model_directory), diff_list))


def custom_dict_diff(first_dict, second_dict):
    diff_dict = {}
    for k, v in second_dict.items():
        orig_v = first_dict.get(k)
        if orig_v is None:
            diff_dict[k] = v
            continue
        if orig_v != v:
            if isinstance(v, dict) and isinstance(orig_v, dict):
                result_dict = custom_dict_diff(orig_v, v)
                if result_dict != {}:
                    diff_dict[k] = custom_dict_diff(orig_v, v)
            else:
                diff_dict[k] = v
    return diff_dict


def compare_two_lists_of_objects_attribute_level(first_list: List[OTLObject], second_list: List[OTLObject],
                                                 model_directory: Path = None) -> List:
    """
    Given two lists of objects return the differences from the second list compared to the first list.
    Assumes both lists have objects with a unique assetId. Returns partial objects (on attribute level)
    from the second list when unmatched with the first list. """
    if model_directory is None:
        current_file_path = Path(__file__)
        model_directory = current_file_path.parent.parent.parent

    l1 = list(map(lambda x: create_dict_from_asset(x), first_list))
    verify_asset_id_is_unique_within_list(l1)

    l2 = list(map(lambda x: create_dict_from_asset(x), second_list))
    verify_asset_id_is_unique_within_list(l2)

    l1_dict_list = {dict_asset['assetId']['identificator']: dict_asset for dict_asset in l1}
    l1_dict_list_keys = list(l1_dict_list.keys())

    diff_list = []
    for d in l2:
        asset_id = d['assetId']['identificator']
        if asset_id not in l1_dict_list_keys:
            diff_list.append(d)
            continue
        orig_dict = l1_dict_list[asset_id]
        if orig_dict == d:
            continue
        diff_dict = custom_dict_diff(orig_dict, d)
        if diff_dict == {}:
            continue
        diff_dict['assetId'] = {'identificator': asset_id}
        diff_dict['typeURI'] = orig_dict['typeURI']
        diff_list.append(diff_dict)

    return list(map(lambda x: OTLObject.from_dict(x, model_directory), diff_list))


def verify_asset_id_is_unique_within_list(dict_list) -> bool:
    try:
        asset_ids_list_1 = list(map(lambda x: x['assetId']['identificator'], dict_list))
        asset_ids_set_1 = set(asset_ids_list_1)
        if None in asset_ids_set_1:
            raise ValueError('This list has a None value for assetId for at least one asset in this list')
        if len(asset_ids_list_1) != len(asset_ids_set_1):
            raise ValueError("There are non-unique assetId's in assets in this list")
        return True
    except Exception as ex:
        raise ex



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.HoutenConstructieElement import HoutenConstructieElement
from ...Classes.Onderdeel.Funderingspaal import Funderingspaal
from ...Datatypes.KwantWrdInCentimeter import KwantWrdInCentimeter, KwantWrdInCentimeterWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class HoutenHeipaal(HoutenConstructieElement, Funderingspaal):
    """De houten paal wordt in de grond gebracht door deze in een hei-installatie te plaatsen waarna men er een zwaar gewicht (heiblok) op laat vallen. De grond onder de paal wordt verdreven en verdicht waardoor de draagkracht groter wordt."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoutenHeipaal'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Behuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Grondanker')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Hoppinzuil')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#NietWeggebondenDetectie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SteunStandaard')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Ventilatie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersbord')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Waarschuwingslantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ZenderOntvangerToegang')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel')

        self._diameterPaalschacht = OTLAttribuut(field=KwantWrdInCentimeter,
                                                 naam='diameterPaalschacht',
                                                 label='diameter paalschacht',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoutenHeipaal.diameterPaalschacht',
                                                 definition='Diameter van de paalschacht in centimeter.',
                                                 owner=self)

    @property
    def diameterPaalschacht(self) -> KwantWrdInCentimeterWaarden:
        """Diameter van de paalschacht in centimeter."""
        return self._diameterPaalschacht.get_waarde()

    @diameterPaalschacht.setter
    def diameterPaalschacht(self, value):
        self._diameterPaalschacht.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlEcoLooprichelType(KeuzelijstField):
    """Types van looprichel."""
    naam = 'KlEcoLooprichelType'
    label = 'Looprichel type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlEcoLooprichelType'
    definition = 'Types van looprichel.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlEcoLooprichelType'
    options = {
        'beton': KeuzelijstWaarde(invulwaarde='beton',
                                  label='beton',
                                  status='ingebruik',
                                  definitie='Een betonnen looprichel.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEcoLooprichelType/beton'),
        'doorlopende-natuurlijke-oever': KeuzelijstWaarde(invulwaarde='doorlopende-natuurlijke-oever',
                                                          label='doorlopende natuurlijke oever',
                                                          status='ingebruik',
                                                          definitie='Een doorlopende natuurlijke oever.',
                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEcoLooprichelType/doorlopende-natuurlijke-oever'),
        'hout': KeuzelijstWaarde(invulwaarde='hout',
                                 label='hout',
                                 status='ingebruik',
                                 definitie='Een houten looprichel.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEcoLooprichelType/hout'),
        'schanskorven': KeuzelijstWaarde(invulwaarde='schanskorven',
                                         label='schanskorven',
                                         status='ingebruik',
                                         definitie='Een oever bestaande uit schanskorven.',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEcoLooprichelType/schanskorven')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTypeHorizontalePlaat(KeuzelijstField):
    """Het type horizontale plaat."""
    naam = 'KlTypeHorizontalePlaat'
    label = 'Type horizontale plaat'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#KlTypeHorizontalePlaat'
    definition = 'Het type horizontale plaat.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTypeHorizontalePlaat'
    options = {
        'dakplaat': KeuzelijstWaarde(invulwaarde='dakplaat',
                                     label='Dakplaat',
                                     status='ingebruik',
                                     definitie='Plaat die het dak van een constructie vormt.',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeHorizontalePlaat/dakplaat'),
        'onderplaat': KeuzelijstWaarde(invulwaarde='onderplaat',
                                       label='Onderplaat',
                                       status='ingebruik',
                                       definitie='Plaat die de bodem/vloer vormt van een constructie. Ook bodemplaat of vloerplaat genoemd.',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeHorizontalePlaat/onderplaat'),
        'tussenplaat': KeuzelijstWaarde(invulwaarde='tussenplaat',
                                        label='Tussenplaat',
                                        status='ingebruik',
                                        definitie='Plaat tussen twee kunstwerken, bv. kokers.',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeHorizontalePlaat/tussenplaat')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlVoedingskabelTypeSpecificatie(KeuzelijstField):
    """Lijst met mogelijke specificaties van het type van de voedingskabel volgens een vaste lijst om bv. de brandklasse mee te geven."""
    naam = 'KlVoedingskabelTypeSpecificatie'
    label = 'Voedingskabel type specificatie'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlVoedingskabelTypeSpecificatie'
    definition = 'Lijst met mogelijke specificaties van het type van de voedingskabel volgens een vaste lijst om bv. de brandklasse mee te geven.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlVoedingskabelTypeSpecificatie'
    options = {
        'cca': KeuzelijstWaarde(invulwaarde='cca',
                                label='Cca',
                                status='ingebruik',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelTypeSpecificatie/cca'),
        'cca-a1': KeuzelijstWaarde(invulwaarde='cca-a1',
                                   label='Cca-a1',
                                   status='ingebruik',
                                   definitie='Halogeenvrije installatiekabels voor binnen.',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelTypeSpecificatie/cca-a1'),
        'cca-a3': KeuzelijstWaarde(invulwaarde='cca-a3',
                                   label='Cca-a3',
                                   status='ingebruik',
                                   definitie='Installatiekabels voor binnen en buiten.',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelTypeSpecificatie/cca-a3'),
        'cca-a3-d2-s3': KeuzelijstWaarde(invulwaarde='cca-a3-d2-s3',
                                         label='Cca-a3 d2 s3',
                                         status='ingebruik',
                                         definitie='Gewapende energiekabels met koperen geleiders voor binnen, buiten en ondergronds gebruik.',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelTypeSpecificatie/cca-a3-d2-s3'),
        'cca-d2': KeuzelijstWaarde(invulwaarde='cca-d2',
                                   label='Cca-d2',
                                   status='ingebruik',
                                   definitie='Installatiekabels voor binnen en buiten.',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelTypeSpecificatie/cca-d2'),
        'cca-s1': KeuzelijstWaarde(invulwaarde='cca-s1',
                                   label='Cca-s1',
                                   status='ingebruik',
                                   definitie='Halogeenvrije installatiekabels voor binnen.',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelTypeSpecificatie/cca-s1'),
        'cca-s1-d2-a1': KeuzelijstWaarde(invulwaarde='cca-s1-d2-a1',
                                         label='Cca-s1 d2 a1',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelTypeSpecificatie/cca-s1-d2-a1'),
        'cca-s1-d2-a2': KeuzelijstWaarde(invulwaarde='cca-s1-d2-a2',
                                         label='Cca-s1 d2 a2',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelTypeSpecificatie/cca-s1-d2-a2'),
        'cca-s1-d2-a3': KeuzelijstWaarde(invulwaarde='cca-s1-d2-a3',
                                         label='Cca-s1 d2 a3',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelTypeSpecificatie/cca-s1-d2-a3'),
        'cca-s3': KeuzelijstWaarde(invulwaarde='cca-s3',
                                   label='Cca-s3',
                                   status='ingebruik',
                                   definitie='Installatiekabels voor binnen en buiten.',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelTypeSpecificatie/cca-s3'),
        'cca-s3-d2-a3': KeuzelijstWaarde(invulwaarde='cca-s3-d2-a3',
                                         label='Cca-s3 d2 a3',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelTypeSpecificatie/cca-s3-d2-a3'),
        'eca': KeuzelijstWaarde(invulwaarde='eca',
                                label='Eca',
                                status='ingebruik',
                                definitie='Niet-gewapende energiekabels met aluminium geleiders voor buiten en ondergronds gebruik.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelTypeSpecificatie/eca'),
        'rf1.5h': KeuzelijstWaarde(invulwaarde='rf1.5h',
                                   label='Rf1.5h',
                                   status='ingebruik',
                                   definitie='Halogeenvrije energiekabels met functiebehoud Rf1,5h.',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelTypeSpecificatie/rf1.5h'),
        'rf1h': KeuzelijstWaarde(invulwaarde='rf1h',
                                 label='Rf1h',
                                 status='ingebruik',
                                 definitie='Halogeenvrije energiekabels met functiebehoud Rf1h.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelTypeSpecificatie/rf1h')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from typing import List
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Kast import Kast
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class IndoorKast(Kast):
    """Behuizing in de vorm van een kast voor gebruik in binnenruimtes."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IndoorKast'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Toegangselement')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Weegcomputer')

        self._mplan = OTLAttribuut(field=DtcDocument,
                                   naam='mplan',
                                   label='m-plan',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IndoorKast.mplan',
                                   usagenote='Bestanden van het type dwg of pdf.',
                                   kardinaliteit_max='*',
                                   definition='Mechanisch plan van de volledige installatie. Er wordt 1 plan toegevoegd per installatie/techniek die op de kast is aangesloten.',
                                   owner=self)

    @property
    def mplan(self) -> List[DtcDocumentWaarden]:
        """Mechanisch plan van de volledige installatie. Er wordt 1 plan toegevoegd per installatie/techniek die op de kast is aangesloten."""
        return self._mplan.get_waarde()

    @mplan.setter
    def mplan(self, value):
        self._mplan.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlDekselKlasse(KeuzelijstField):
    """Klassen van het deksel van de bovenbouw."""
    naam = 'KlDekselKlasse'
    label = 'Dekselklasse'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlDekselKlasse'
    definition = 'Klassen van het deksel van de bovenbouw.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlDekselKlasse'
    options = {
        'C250-(voetpad)': KeuzelijstWaarde(invulwaarde='C250-(voetpad)',
                                           label='C250 (voetpad)',
                                           status='ingebruik',
                                           definitie='C250 (voetpad)',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDekselKlasse/C250-(voetpad)'),
        'D400-(rijweg)': KeuzelijstWaarde(invulwaarde='D400-(rijweg)',
                                          label='D400 (rijweg)',
                                          status='ingebruik',
                                          definitie='D400 (rijweg)',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDekselKlasse/D400-(rijweg)'),
        'E600-(rijweg-voor-zwaar-verkeer)': KeuzelijstWaarde(invulwaarde='E600-(rijweg-voor-zwaar-verkeer)',
                                                             label='E600 (rijweg voor zwaar verkeer)',
                                                             status='ingebruik',
                                                             definitie='E600 (rijweg voor zwaar verkeer)',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDekselKlasse/E600-(rijweg-voor-zwaar-verkeer)'),
        'F900-(vliegvelden)': KeuzelijstWaarde(invulwaarde='F900-(vliegvelden)',
                                               label='F900 (vliegvelden)',
                                               status='ingebruik',
                                               definitie='F900 (vliegvelden)',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDekselKlasse/F900-(vliegvelden)')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KlSmeringType import KlSmeringType
from ...Datatypes.KwantWrdInKubiekeCentimeter import KwantWrdInKubiekeCentimeter, KwantWrdInKubiekeCentimeterWaarden
from ...Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Lager(AIMNaamObject, PuntGeometrie):
    """Abstracte die alle relaties van lagers verzamelt."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Lager'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aandrijfas')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Lagerblok')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wormschroef')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Overbrenging')

        self._breedte = OTLAttribuut(field=KwantWrdInMillimeter,
                                     naam='breedte',
                                     label='breedte',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Lager.breedte',
                                     definition='De breedte van het lager. Indien je de lager bekijkt als een cilinder, dan spreken we hier over de hoogte van de cilinder.',
                                     owner=self)

        self._hoeveelheidVetPerSmeerronde = OTLAttribuut(field=KwantWrdInKubiekeCentimeter,
                                                         naam='hoeveelheidVetPerSmeerronde',
                                                         label='hoeveelheid vet per smeerronde',
                                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Lager.hoeveelheidVetPerSmeerronde',
                                                         definition='Geeft aan hoeveel vet er per smeerronde moet worden gebruikt om het lager goed te smeren.',
                                                         owner=self)

        self._inwendigeDiameter = OTLAttribuut(field=KwantWrdInMillimeter,
                                               naam='inwendigeDiameter',
                                               label='inwendige diameter',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Lager.inwendigeDiameter',
                                               definition='De inwendige diameter van het lager bepaalt hoe groot de as die in het lager beweegt kan zijn.',
                                               owner=self)

        self._typeSmering = OTLAttribuut(field=KlSmeringType,
                                         naam='typeSmering',
                                         label='type smering',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Lager.typeSmering',
                                         definition='Geeft aan op welke wijze het lager gesmeerd wordt.',
                                         owner=self)

        self._uitwendigeDiameter = OTLAttribuut(field=KwantWrdInMillimeter,
                                                naam='uitwendigeDiameter',
                                                label='uitwendige diameter',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Lager.uitwendigeDiameter',
                                                definition='De uitwendige diameter van het lager.',
                                                owner=self)

    @property
    def breedte(self) -> KwantWrdInMillimeterWaarden:
        """De breedte van het lager. Indien je de lager bekijkt als een cilinder, dan spreken we hier over de hoogte van de cilinder."""
        return self._breedte.get_waarde()

    @breedte.setter
    def breedte(self, value):
        self._breedte.set_waarde(value, owner=self)

    @property
    def hoeveelheidVetPerSmeerronde(self) -> KwantWrdInKubiekeCentimeterWaarden:
        """Geeft aan hoeveel vet er per smeerronde moet worden gebruikt om het lager goed te smeren."""
        return self._hoeveelheidVetPerSmeerronde.get_waarde()

    @hoeveelheidVetPerSmeerronde.setter
    def hoeveelheidVetPerSmeerronde(self, value):
        self._hoeveelheidVetPerSmeerronde.set_waarde(value, owner=self)

    @property
    def inwendigeDiameter(self) -> KwantWrdInMillimeterWaarden:
        """De inwendige diameter van het lager bepaalt hoe groot de as die in het lager beweegt kan zijn."""
        return self._inwendigeDiameter.get_waarde()

    @inwendigeDiameter.setter
    def inwendigeDiameter(self, value):
        self._inwendigeDiameter.set_waarde(value, owner=self)

    @property
    def typeSmering(self) -> str:
        """Geeft aan op welke wijze het lager gesmeerd wordt."""
        return self._typeSmering.get_waarde()

    @typeSmering.setter
    def typeSmering(self, value):
        self._typeSmering.set_waarde(value, owner=self)

    @property
    def uitwendigeDiameter(self) -> KwantWrdInMillimeterWaarden:
        """De uitwendige diameter van het lager."""
        return self._uitwendigeDiameter.get_waarde()

    @uitwendigeDiameter.setter
    def uitwendigeDiameter(self, value):
        self._uitwendigeDiameter.set_waarde(value, owner=self)



# coding=utf-8
from typing import List
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.SoftwareToegang import SoftwareToegang
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.DtcSoftwarePoortconfiguratie import DtcSoftwarePoortconfiguratie, DtcSoftwarePoortconfiguratieWaarden
from ...Datatypes.KlSoftwareLicentie import KlSoftwareLicentie
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField
from otlmow_model.OtlmowModel.BaseClasses.URIField import URIField
from otlmow_model.OtlmowModel.GeometrieTypes.GeenGeometrie import GeenGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Software(SoftwareToegang, GeenGeometrie):
    """Geheel van computerprogramma's met bijbehorende data."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Software'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsSWGehostOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#HardwareToegang')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsSWGehostOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hardware')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsSWGehostOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VirtueleServer')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsSWOnderdeelVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#IVRIComponent')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsSWOnderdeelVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ITSapp')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsSWOnderdeelVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#RIS')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsSWOnderdeelVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Software')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsSWOnderdeelVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#TLCfiPoort')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Detectielus')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Sensor')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LogischePoort')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PLC')

        self._aangebodenServices = OTLAttribuut(field=DtcDocument,
                                                naam='aangebodenServices',
                                                label='aangeboden services',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Software.aangebodenServices',
                                                definition='De endpoints van diensten.',
                                                owner=self)

        self._buildnummer = OTLAttribuut(field=StringField,
                                         naam='buildnummer',
                                         label='buildnummer',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Software.buildnummer',
                                         definition='De software build.',
                                         owner=self)

        self._dependencies = OTLAttribuut(field=DtcDocument,
                                          naam='dependencies',
                                          label='dependencies',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Software.dependencies',
                                          definition='Afhankelijkheden met andere diensten.',
                                          owner=self)

        self._documentatie = OTLAttribuut(field=StringField,
                                          naam='documentatie',
                                          label='documentatie',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Software.documentatie',
                                          usagenote='Attribuut uit gebruik sinds versie 2.1.0 ',
                                          deprecated_version='2.1.0',
                                          definition='Link naar documentatie over de software.',
                                          owner=self)

        self._licentie = OTLAttribuut(field=KlSoftwareLicentie,
                                      naam='licentie',
                                      label='licentie',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Software.licentie',
                                      definition='De licentievorm van de software (bv. commercieel, shareware, freeware, open source [BSD, Apache, GPL],...).',
                                      owner=self)

        self._onlineDocumentatie = OTLAttribuut(field=URIField,
                                                naam='onlineDocumentatie',
                                                label='online documentatie',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Software.onlineDocumentatie',
                                                definition='De url waarop documentatie over de software te vinden is.',
                                                owner=self)

        self._poortenconfiguratie = OTLAttribuut(field=DtcSoftwarePoortconfiguratie,
                                                 naam='poortenconfiguratie',
                                                 label='poortenconfiguratie',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Software.poortenconfiguratie',
                                                 kardinaliteit_max='*',
                                                 definition='Beschrijft welke poort voor welke service gebruikt wordt.',
                                                 owner=self)

        self._versie = OTLAttribuut(field=StringField,
                                    naam='versie',
                                    label='versie',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Software.versie',
                                    definition='Het versienummer van de software.',
                                    owner=self)

    @property
    def aangebodenServices(self) -> DtcDocumentWaarden:
        """De endpoints van diensten."""
        return self._aangebodenServices.get_waarde()

    @aangebodenServices.setter
    def aangebodenServices(self, value):
        self._aangebodenServices.set_waarde(value, owner=self)

    @property
    def buildnummer(self) -> str:
        """De software build."""
        return self._buildnummer.get_waarde()

    @buildnummer.setter
    def buildnummer(self, value):
        self._buildnummer.set_waarde(value, owner=self)

    @property
    def dependencies(self) -> DtcDocumentWaarden:
        """Afhankelijkheden met andere diensten."""
        return self._dependencies.get_waarde()

    @dependencies.setter
    def dependencies(self, value):
        self._dependencies.set_waarde(value, owner=self)

    @property
    def documentatie(self) -> str:
        """Link naar documentatie over de software."""
        return self._documentatie.get_waarde()

    @documentatie.setter
    def documentatie(self, value):
        self._documentatie.set_waarde(value, owner=self)

    @property
    def licentie(self) -> str:
        """De licentievorm van de software (bv. commercieel, shareware, freeware, open source [BSD, Apache, GPL],...)."""
        return self._licentie.get_waarde()

    @licentie.setter
    def licentie(self, value):
        self._licentie.set_waarde(value, owner=self)

    @property
    def onlineDocumentatie(self) -> str:
        """De url waarop documentatie over de software te vinden is."""
        return self._onlineDocumentatie.get_waarde()

    @onlineDocumentatie.setter
    def onlineDocumentatie(self, value):
        self._onlineDocumentatie.set_waarde(value, owner=self)

    @property
    def poortenconfiguratie(self) -> List[DtcSoftwarePoortconfiguratieWaarden]:
        """Beschrijft welke poort voor welke service gebruikt wordt."""
        return self._poortenconfiguratie.get_waarde()

    @poortenconfiguratie.setter
    def poortenconfiguratie(self, value):
        self._poortenconfiguratie.set_waarde(value, owner=self)

    @property
    def versie(self) -> str:
        """Het versienummer van de software."""
        return self._versie.get_waarde()

    @versie.setter
    def versie(self, value):
        self._versie.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlStuurklepMerk import KlStuurklepMerk
from ...Datatypes.KlStuurklepModelnaam import KlStuurklepModelnaam
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Stuurklep(AIMNaamObject, PuntGeometrie):
    """Een afsluiter die vanop afstand bediend wordt om te bepalen of er al of niet vloeistof of gas door de leiding stroomt."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stuurklep'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Persleiding')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PLC')

        self._merk = OTLAttribuut(field=KlStuurklepMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stuurklep.merk',
                                  definition='De merknaam van de stuurklep.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlStuurklepModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stuurklep.modelnaam',
                                       definition='De modelnaam van de stuurklep.',
                                       owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stuurklep.technischeFiche',
                                             definition='Technische fiche van de stuurklep.',
                                             owner=self)

    @property
    def merk(self) -> str:
        """De merknaam van de stuurklep."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de stuurklep."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """Technische fiche van de stuurklep."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlSlotGebruik(KeuzelijstField):
    """Keuzelijst voor de kant langs dewelke het slot geïnstalleerd kan worden. Je kijkt hierbij naar de deur vanuit de kant dat je de deur openduwt (en niet de kant waarlangs je zou moeten trekken)."""
    naam = 'KlSlotGebruik'
    label = 'Slot gebruik'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlSlotGebruik'
    definition = 'Keuzelijst voor de kant langs dewelke het slot geïnstalleerd kan worden. Je kijkt hierbij naar de deur vanuit de kant dat je de deur openduwt (en niet de kant waarlangs je zou moeten trekken).'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlSlotGebruik'
    options = {
        'links': KeuzelijstWaarde(invulwaarde='links',
                                  label='links',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSlotGebruik/links'),
        'omkeerbaar': KeuzelijstWaarde(invulwaarde='omkeerbaar',
                                       label='omkeerbaar',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSlotGebruik/omkeerbaar'),
        'rechts': KeuzelijstWaarde(invulwaarde='rechts',
                                   label='rechts',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSlotGebruik/rechts')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.SoftwareToegang import SoftwareToegang
from ...Datatypes.DtcSoftwarePoortconfiguratie import DtcSoftwarePoortconfiguratie, DtcSoftwarePoortconfiguratieWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class LogischePoort(SoftwareToegang):
    """Een 'logische' connectie waaraan een nummer tussen 0 en 65536 wordt toegewezen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LogischePoort'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Detectielus')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Sensor')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Software')

        self._poortconfiguratie = OTLAttribuut(field=DtcSoftwarePoortconfiguratie,
                                               naam='poortconfiguratie',
                                               label='poortconfiguratie',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LogischePoort.poortconfiguratie',
                                               definition='Type TCP of UDP service.',
                                               owner=self)

    @property
    def poortconfiguratie(self) -> DtcSoftwarePoortconfiguratieWaarden:
        """Type TCP of UDP service."""
        return self._poortconfiguratie.get_waarde()

    @poortconfiguratie.setter
    def poortconfiguratie(self, value):
        self._poortconfiguratie.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Buitenkast import Buitenkast
from ...Datatypes.KlHulppostkastType import KlHulppostkastType


# Generated with OTLClassCreator. To modify: extend, do not edit
class Hulppostkast(Buitenkast):
    """Een kast waarin verschillende onderdelen verzameld worden voor bijstand in noodgevallen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hulppostkast'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Toegangselement')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandblusser')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandhaspel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hydrant')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomToestel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Pictogram')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stopcontact')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verwarmingselement')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hulppost')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Vluchtganginrichting')

        self._type = OTLAttribuut(field=KlHulppostkastType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hulppostkast.type',
                                  definition='Classificatie van de hulppostkast op basis van de inhoud en vorm volgens gangbare standaarden.',
                                  owner=self)

    @property
    def type(self) -> str:
        """Classificatie van de hulppostkast op basis van de inhoud en vorm volgens gangbare standaarden."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Kabelgeleiding import Kabelgeleiding
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KlAlgMateriaal import KlAlgMateriaal
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Kabelgoot(Kabelgeleiding, VlakGeometrie):
    """Een inrichting die ervoor zorgt dat een kabel beschermd is tegen beschadiging en/of op een gecontroleerde plaats blijft hangen of liggen. Een kabelgoot is doorgaans een halfopen constructie. Er bestaan ook kabelgoten die door een deksel gesloten kunnen worden."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kabelgoot'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._isGesloten = OTLAttribuut(field=BooleanField,
                                        naam='isGesloten',
                                        label='is gesloten',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kabelgoot.isGesloten',
                                        definition='Geeft aan of de goot volledig gesloten is.',
                                        owner=self)

        self._materiaal = OTLAttribuut(field=KlAlgMateriaal,
                                       naam='materiaal',
                                       label='materiaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kabelgoot.materiaal',
                                       definition='Het materiaal waaruit de kabelgoot (hoofdzakelijk) is gemaakt.',
                                       owner=self)

    @property
    def isGesloten(self) -> bool:
        """Geeft aan of de goot volledig gesloten is."""
        return self._isGesloten.get_waarde()

    @isGesloten.setter
    def isGesloten(self, value):
        self._isGesloten.set_waarde(value, owner=self)

    @property
    def materiaal(self) -> str:
        """Het materiaal waaruit de kabelgoot (hoofdzakelijk) is gemaakt."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Kokercomplex(AIMNaamObject, LijnGeometrie, VlakGeometrie):
    """Een constructie met een gesloten doorsnede dat over de hele lengte doorloopt, continu ondersteund, bestaande uit 1 of meerdere kokercellen die 2 of meer locaties verbindt, met 1 of meerdere in- en uitgangen, ongeacht de toepassing."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kokercomplex'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._ligtFunderingInOpRandWaterweg = OTLAttribuut(field=BooleanField,
                                                           naam='ligtFunderingInOpRandWaterweg',
                                                           label='ligt fundering in of op de rand van de waterweg',
                                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kokercomplex.ligtFunderingInOpRandWaterweg',
                                                           definition='Geeft aan of de fundering van het landhoofd in of op de rand van de waterweg ligt.',
                                                           owner=self)

        self._ligtFunderingsaanzetOnderBodem = OTLAttribuut(field=BooleanField,
                                                            naam='ligtFunderingsaanzetOnderBodem',
                                                            label='ligt funderingsaanzet onder de bodem',
                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kokercomplex.ligtFunderingsaanzetOnderBodem',
                                                            definition='Geeft aan of de funderingsaanzet al dan niet onder de bodem ligt.',
                                                            owner=self)

    @property
    def ligtFunderingInOpRandWaterweg(self) -> bool:
        """Geeft aan of de fundering van het landhoofd in of op de rand van de waterweg ligt."""
        return self._ligtFunderingInOpRandWaterweg.get_waarde()

    @ligtFunderingInOpRandWaterweg.setter
    def ligtFunderingInOpRandWaterweg(self, value):
        self._ligtFunderingInOpRandWaterweg.set_waarde(value, owner=self)

    @property
    def ligtFunderingsaanzetOnderBodem(self) -> bool:
        """Geeft aan of de funderingsaanzet al dan niet onder de bodem ligt."""
        return self._ligtFunderingsaanzetOnderBodem.get_waarde()

    @ligtFunderingsaanzetOnderBodem.setter
    def ligtFunderingsaanzetOnderBodem(self, value):
        self._ligtFunderingsaanzetOnderBodem.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Niveaumeting import Niveaumeting
from ...Datatypes.KlUltrasoonNiveaumetingMerk import KlUltrasoonNiveaumetingMerk
from ...Datatypes.KlUltrasoonNiveaumetingModelnaam import KlUltrasoonNiveaumetingModelnaam


# Generated with OTLClassCreator. To modify: extend, do not edit
class UltrasoonNiveaumeting(Niveaumeting):
    """Een inrichting voor het bepalen van het peil van een vloeistof (bv. het peil van een waterloop, uitgedrukt in meter TAW). De sensor meet het tijdsinterval tussen het uitzenden en ontvangen van geluidsgolven en bepaald hiermee de afstand (hoogte) tot een object (water). Het resultaat wordt omgezet in een uitleesbaar signaal. """

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#UltrasoonNiveaumeting'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._merk = OTLAttribuut(field=KlUltrasoonNiveaumetingMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#UltrasoonNiveaumeting.merk',
                                  definition='De merknaam van de ultrasoon niveaumeting.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlUltrasoonNiveaumetingModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#UltrasoonNiveaumeting.modelnaam',
                                       definition='De modelnaam van de ultrasoon niveaumeting.',
                                       owner=self)

    @property
    def merk(self) -> str:
        """De merknaam van de ultrasoon niveaumeting."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de ultrasoon niveaumeting."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.Abstracten.KlassiekeFundering import KlassiekeFundering
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class FunderingOpStaal(KlassiekeFundering, PuntGeometrie, VlakGeometrie):
    """Fundering die direct op de draagkrachtige bodem rust. Kunnen uitgevoerd zijn als alleenstaande zolen of als doorlopende stroken."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#FunderingOpStaal'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Behuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Grondanker')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Hoppinzuil')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#NietWeggebondenDetectie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SteunStandaard')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Ventilatie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersbord')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Waarschuwingslantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ZenderOntvangerToegang')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#GewapendeGrond')



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.NaampadObject import NaampadObject
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlMIVEenheidType import KlMIVEenheidType
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class MIVInstallatie(NaampadObject, VlakGeometrie):
    """Een MIV eenheid die instaat voor de verwerking van gegevens van lussen op een bepaalde locatie, hetzij als satelliet-eenheid hetzij als centrale eenheid voor de combinatie van verschillende eenheden."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#MIVInstallatie'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    deprecated_version = '2.9.0'

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#MIVCommunicatiekaart', deprecated='2.9.0')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#MIVVoedingsmodule', deprecated='2.9.0')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#MIVInstallatie', deprecated='2.9.0')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#MIVVoedingsmodule', deprecated='2.9.0')

        self._lusConfig = OTLAttribuut(field=DtcDocument,
                                       naam='lusConfig',
                                       label='lus config',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#MIVInstallatie.lusConfig',
                                       usagenote='Klasse uit gebruik sinds versie 2.9.0 ',
                                       deprecated_version='2.9.0',
                                       definition='Een definierende tabel die relatie legt tussen meetpuntnummer lusvolgorde nummer en de GPS locatie.',
                                       owner=self)

        self._technischeDocumentatie = OTLAttribuut(field=DtcDocument,
                                                    naam='technischeDocumentatie',
                                                    label='technische documentatie',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#MIVInstallatie.technischeDocumentatie',
                                                    usagenote='Klasse uit gebruik sinds versie 2.9.0 ',
                                                    deprecated_version='2.9.0',
                                                    definition='Documentatie van de onderdelen: LVE / luskaart / communicatiekaart, configurator, ...',
                                                    owner=self)

        self._type = OTLAttribuut(field=KlMIVEenheidType,
                                  naam='type',
                                  label='type MIV installatie',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#MIVInstallatie.type',
                                  usagenote='Klasse uit gebruik sinds versie 2.9.0 ',
                                  deprecated_version='2.9.0',
                                  definition='Het type volgens de gebruikte technologie en inzet in een groter geheel.',
                                  owner=self)

    @property
    def lusConfig(self) -> DtcDocumentWaarden:
        """Een definierende tabel die relatie legt tussen meetpuntnummer lusvolgorde nummer en de GPS locatie."""
        return self._lusConfig.get_waarde()

    @lusConfig.setter
    def lusConfig(self, value):
        self._lusConfig.set_waarde(value, owner=self)

    @property
    def technischeDocumentatie(self) -> DtcDocumentWaarden:
        """Documentatie van de onderdelen: LVE / luskaart / communicatiekaart, configurator, ..."""
        return self._technischeDocumentatie.get_waarde()

    @technischeDocumentatie.setter
    def technischeDocumentatie(self, value):
        self._technischeDocumentatie.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Het type volgens de gebruikte technologie en inzet in een groter geheel."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.VRModuleMetFirmware import VRModuleMetFirmware
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.DteIPv4Adres import DteIPv4Adres, DteIPv4AdresWaarden
from ...Datatypes.KlVrComKaartTypeOpslaggeheugen import KlVrComKaartTypeOpslaggeheugen
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField


# Generated with OTLClassCreator. To modify: extend, do not edit
class VRCommunicatiekaart(VRModuleMetFirmware):
    """Modem die alle toestandswijzigingen van de stuurkaart doorgeeft aan het afstandsbewakingssysteem. De module maakt continue een backup van alle log en data gegevens en slaat deze op op de aanwezige SD kaart. Tevens wordt de module ook gebruikt om vanop afstand te kunnen communiceren met de regelaar"""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VRCommunicatiekaart'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._dnsNaam = OTLAttribuut(field=StringField,
                                     naam='dnsNaam',
                                     label='DNS naam',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VRCommunicatiekaart.dnsNaam',
                                     definition='De DNSNaam (ook "volledige domein naam" genoemd ) is een unieke naam binnen het Domain Name System (DNS), het naamgevingssysteem waarmee computers, webservers, diensten en toepassing op een unieke manier kunnen worden geïdentificeerd. Deze bevat zowel de hostname en de top level domein naam bv. 120c8-ar1.belfa.be.',
                                     owner=self)

        self._heeftSmartguard = OTLAttribuut(field=BooleanField,
                                             naam='heeftSmartguard',
                                             label='heeft smartguard',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VRCommunicatiekaart.heeftSmartguard',
                                             definition='Smartguard aanwezig?',
                                             owner=self)

        self._ipAdres = OTLAttribuut(field=DteIPv4Adres,
                                     naam='ipAdres',
                                     label='ipv4 adres',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VRCommunicatiekaart.ipAdres',
                                     definition='IP-adres.',
                                     owner=self)

        self._telefoonnummer = OTLAttribuut(field=StringField,
                                            naam='telefoonnummer',
                                            label='telefoonnummer',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VRCommunicatiekaart.telefoonnummer',
                                            definition='Telefoonnummer.',
                                            owner=self)

        self._typeGeheugen = OTLAttribuut(field=KlVrComKaartTypeOpslaggeheugen,
                                          naam='typeGeheugen',
                                          label='type geheugen',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VRCommunicatiekaart.typeGeheugen',
                                          definition='Type opslaggeheugen op de aanwezige SD-kaart.',
                                          owner=self)

        self._uitvoering = OTLAttribuut(field=StringField,
                                        naam='uitvoering',
                                        label='uitvoering',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VRCommunicatiekaart.uitvoering',
                                        definition='Type van communicatiekaart.',
                                        owner=self)

    @property
    def dnsNaam(self) -> str:
        """De DNSNaam (ook "volledige domein naam" genoemd ) is een unieke naam binnen het Domain Name System (DNS), het naamgevingssysteem waarmee computers, webservers, diensten en toepassing op een unieke manier kunnen worden geïdentificeerd. Deze bevat zowel de hostname en de top level domein naam bv. 120c8-ar1.belfa.be."""
        return self._dnsNaam.get_waarde()

    @dnsNaam.setter
    def dnsNaam(self, value):
        self._dnsNaam.set_waarde(value, owner=self)

    @property
    def heeftSmartguard(self) -> bool:
        """Smartguard aanwezig?"""
        return self._heeftSmartguard.get_waarde()

    @heeftSmartguard.setter
    def heeftSmartguard(self, value):
        self._heeftSmartguard.set_waarde(value, owner=self)

    @property
    def ipAdres(self) -> DteIPv4AdresWaarden:
        """IP-adres."""
        return self._ipAdres.get_waarde()

    @ipAdres.setter
    def ipAdres(self, value):
        self._ipAdres.set_waarde(value, owner=self)

    @property
    def telefoonnummer(self) -> str:
        """Telefoonnummer."""
        return self._telefoonnummer.get_waarde()

    @telefoonnummer.setter
    def telefoonnummer(self, value):
        self._telefoonnummer.set_waarde(value, owner=self)

    @property
    def typeGeheugen(self) -> str:
        """Type opslaggeheugen op de aanwezige SD-kaart."""
        return self._typeGeheugen.get_waarde()

    @typeGeheugen.setter
    def typeGeheugen(self, value):
        self._typeGeheugen.set_waarde(value, owner=self)

    @property
    def uitvoering(self) -> str:
        """Type van communicatiekaart."""
        return self._uitvoering.get_waarde()

    @uitvoering.setter
    def uitvoering(self, value):
        self._uitvoering.set_waarde(value, owner=self)
